@@ -62,7 +62,7 @@ class Command(object):
         try:
             self.run(args)
         except Exception:
-            self.logger.error("ERROR: %s" % str(sys.exc_info()[1]))
+            sys.stderr.write("ERROR: %s \n" % str(sys.exc_info()[1]))
             sys.exit(1)
         except KeyboardInterrupt:
             sys.exit(1)
@@ -88,12 +88,12 @@ class ScaleCommand(Command):
         try:
             options, arg_else = self.parse_args(args)
         except BadOptionError:
-            self.logger.error("ERROR: %s" % str(sys.exc_info()[1]))
+            sys.stderr.write("ERROR: %s \n" % str(sys.exc_info()[1]))
             return
 
         # scale services
         if not options.envname:
-            self.logger.error("ERROR: %s" % "please provide environment name")
+            sys.stderr.write("ERROR: %s \s" % "please provide environment name")
         else:
             env = Environment.get_environment_by_name(options.envname)
             scaleable_service_list = env.get_scaleable_services_list()
@@ -102,13 +102,14 @@ class ScaleCommand(Command):
                 scaled_number = get_userinput_int(
                     "Input the expected instance number for the service [%s] after scaled : " % service.name)
                 if scaled_number <= len(service.machines):
-                    self.logger.info("the scaled number is even smaller than the current scope , escape")
+                    sys.stdout.write("the scaled number is even smaller than the current scope , escape\n")
                 else:
                     service_scale_dict[service] = scaled_number
 
             for service in service_scale_dict:
-                self.logger.info(
-                    "scale the [%s] from %s to %s" % (service.name, len(service.machines), service_scale_dict[service]))
+                sys.stdout.write(
+                    "scale the [%s] from %s to %s \n" % (
+                        service.name, len(service.machines), service_scale_dict[service]))
                 service.scale(service_scale_dict[service])
 
 
@@ -134,9 +135,9 @@ class CleanCommand(Command):
             if is_true(user_input):
                 environment = Environment.get_environment_by_name(name=options.envname)
                 environment.clean()
-                self.logger.info("the environment [%s] has been deleted" % options.envname)
+                sys.stdout.write("the environment [%s] has been deleted \n" % options.envname)
         except BadOptionError:
-            self.logger.error("ERROR: %s" % str(sys.exc_info()[1]))
+            sys.stderr.write("ERROR: %s" % str(sys.exc_info()[1]))
             return
 
 
@@ -152,13 +153,13 @@ class BuildCommand(Command):
         ns = get_userinput_str("Please input the namespace : ").strip()
         splunk_pkg_path = get_userinput_str("Please input the splunk build package path : ").strip()
         if not os.path.exists(splunk_pkg_path):
-            self.logger.error("the splunk pkg path [%s] not existed" % splunk_pkg_path)
+            sys.stderr.write("the splunk pkg path [%s] not existed \n" % splunk_pkg_path)
         build_number = get_userinput_int("Please input the splunk build number: ")
         existed_image = Image.get_image_by_build_id(build_number)
         if existed_image:
-            self.logger.error("the build [%s] of splunk package already existed" % build_number)
+            sys.stderr.write("the build [%s] of splunk package already existed \n" % build_number)
         new_image = Image.build_image("", ns, build_number, splunk_pkg_path)
-        self.logger.info("successfully build the new image [%s]" % new_image.image_name)
+        sys.stdout.write("successfully build the new image [%s] \n" % new_image.image_name)
 
 
 class BootStrapCommand(Command):
@@ -178,16 +179,21 @@ class BootStrapCommand(Command):
         rider_env_name = "%s_%s" % (env_name, env_type)
         old_env = Environment.get_environment_by_name(rider_env_name)
         if old_env:
-            self.logger.warn("the environment %s already exites , please choose another name")
+            sys.stderr.write("the environment %s already exites , please choose another name")
             sys.exit(1)
 
-        image_list = Image.get_all_images()
-        image_choice_list = [image_list[key].image_name for key in image_list.keys()]
+        image_dict = Image.get_all_images()
+        if not image_dict:
+            sys.stderr.write("no available image exists , please use `rider build` to build the image first \n")
+
+        image_choice_list = [image_dict[key].image_name for key in image_dict.keys()]
         image_name = get_userinput_choice(image_choice_list, "Choose the image")
 
         new_env = Environment.create_environment(env_type=env_type, env_name=env_name, image_name=image_name)
         new_env.bootstrap()
 
+        sys.stdout.write("successfully create the environment [%s]" % env_name)
+
 
 class ShowCommand(Command):
     name = "show"
@@ -227,7 +233,7 @@ class ShowCommand(Command):
                                    "ssh authentication"])
                         env = Environment.get_environment_by_name(options.envname)
                         if not env:
-                            self.logger.error("the environment [%s] does not exist " % options.envname)
+                            sys.stderr.write("the environment [%s] does not exist " % options.envname)
                         for service in env.service_list:
                             for machine in service.machines:
                                 table = []
@@ -237,47 +243,39 @@ class ShowCommand(Command):
                                 table.append("root/password")
                                 tb.add_row(table)
                         sys.stdout.write(tb.draw())
+                        sys.stdout.write("\n")
                     else:
                         tb = Texttable()
                         tb.header(["Environments"])
                         for env in Environment.get_environments():
                             tb.add_row([env.env_name])
                         sys.stdout.write(tb.draw())
+                        sys.stdout.write("\n")
                 except BadOptionError:
-                    self.logger.error("ERROR: %s" % str(sys.exc_info()[1]))
+                    sys.stderr.write("ERROR: %s" % str(sys.exc_info()[1]))
                     return
 
-        class EnvTypeCommand(self.__class__):
-            name = "show envtype"
-            subcommand = "envtype"
+        class ImageCommand(self.__class__):
+            name = "show image"
+            subcommand = "image"
             usage = """%prog"""
             summary = "show the information for the matrix"
 
             def __init__(self):
-                super(EnvTypeCommand, self).__init__()
-                self.parser.add_option(Option(
-                    '--envtype',
-                    dest='envtype',
-                    action='store',
-                    default=None,
-                    help="the type of environment"
-                ))
+                super(ImageCommand, self).__init__()
 
             def run(self, args):
-                try:
-                    options, arg_else = self.parse_args(args)
-                    if options.envtype:
-                        pass
-                    else:
-                        pass
-                except BadOptionError:
-                    self.logger.error("ERROR: %s" % str(sys.exc_info()[1]))
-                    return
-
+                images = Image.get_all_images()
+                tb = Texttable()
+                tb.header(["rider support images"])
+                for key in images.keys():
+                    tb.add_row([images[key].image_name])
+                sys.stdout.write(tb.draw())
+                sys.stdout.write("\n")
 
         sub_commands = {
             EnvCommand.subcommand: EnvCommand,
-            EnvTypeCommand.subcommand: EnvTypeCommand
+            ImageCommand.subcommand: ImageCommand
         }
 
         parser_kw = {
