@@ -9,6 +9,12 @@ CONTAINER_NAME_REGEX = '\s+\_\d+\_\s+\_\d+'
 DEFAULT_IMAGE = '10.66.128.203:49153/coreqa/splunk:fig'
 
 
+# import os
+# os.environ["FIG_FILE"] = "/Users/weiwang/work/github/rider/rider/pkg/fig.yml"
+# os.environ["DOCKER_HOST"] = 'tcp://192.168.59.103:2376'
+# os.environ["DOCKER_TLS_VERIFY"] = '1'
+# os.environ["DOCKER_CERT_PATH"] = '/Users/weiwang/.boot2docker/certs/boot2docker-vm'
+
 class Environment(object):
     """
     Represents a rider environment of splunk instances
@@ -27,8 +33,31 @@ class Environment(object):
 
     @property
     def service_list(self):
+        """
+        return a service list of current environment
+
+        :return: service list of current environment
+
+        >>> from rider.environment import Environment
+        >>> myEnv = Environment.create_environment("cluster","jacktestapi")
+        >>> server_list = myEnv.service_list
+        """
         return [Service(service.name, service, self) for service in self._project.get_services()]
 
+    def get_scaleable_services_list(self):
+        """
+        Return all scale-able services as a list of current environment
+
+        :return: all scale-able services as a list of current environment
+
+        >>> from rider.environment import Environment
+        >>> myEnv = Environment.create_environment("cluster","jacktestapi")
+        >>> server_list = myEnv.get_scaleable_services_list()
+        """
+        return [service for service in self.service_list if service.is_scaleable() == True]
+
+        pass
+
     @classmethod
     def create_environment(cls, env_type, env_name, image_name=None):
         """
@@ -42,7 +71,7 @@ class Environment(object):
 
 
         >>> from rider.environment import Environment
-        >>> myEnv = Environment.create_environment("cluster", "jacktestapi2")
+        >>> myEnv = Environment.create_environment("cluster", "jacktestapi")
         """
         if image_name is None:
             image_name = DEFAULT_IMAGE
@@ -88,7 +117,7 @@ class Environment(object):
         :return:    environment object
 
         >>> from rider.environment import Environment
-        >>> env = Environment.get_environments('jacktestapi2_cluster')
+        >>> env = Environment.get_environment_by_name('jacktestapi_cluster')
         """
 
         for env in cls.get_environments():
@@ -116,7 +145,7 @@ class Environment(object):
         :return: list of service name
 
         >>> from rider.environment import  Environment
-        >>> env = Environment.get_environments('jacktestapi2_cluster')
+        >>> env = Environment.get_environment_by_name('jacktestapi_cluster')
         >>> services_name_list = env.get_service_names()
         """
         service_name = []
@@ -128,14 +157,57 @@ class Environment(object):
 
 
     def clean(self):
-        pass
+        """
+        Clean the entire environment by stop and remove the running containers in current environment
+        :return:
+
+        >>> from rider.environment import  Environment
+        >>> env = Environment.get_environment_by_name('jacktestapi_cluster')
+        >>> env.bootstrap()
+        >>> env.clean()
+        """
+        for service in self.service_list:
+            service._service.stop()
+            service._service.remove_stopped(**{"v": True})
 
 
     def up(self):
+        """
+        start environment by start only one container for each services
+        :return:
+
+        >>> from rider.environment import  Environment
+        >>> env = Environment.get_environment_by_name('jacktestapi_cluster')
+        >>> env.up()
+        """
+
         self._project.up()
         pass
 
 
+    def bootstrap(self):
+        """
+        Bootstrap a standard environment
+
+        :return:
+
+        >>> from rider.environment import  Environment
+        >>> env = Environment.get_environment_by_name('jacktestapi_cluster')
+        >>> env.bootstrap()
+
+        """
+
+        if self.env_type == "cluster":
+            self.up()
+            self.indexer.scale(3)
+
+        elif self.env_type == "dst":
+            self.up()
+            self.dsp.scale(3)
+
+        pass
+
+
     def _get_service_dict(self, image_name):
         pre_service_dict = ENV_DICT_MAPPING[ClusterEnvironment.env_type]
         aft_service_dict = []
@@ -182,12 +254,10 @@ ENV_DICT_MAPPING = {
         {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'],
          'links': ['master'], u'name': 'indexer'}],
     DistributedEnvironment.env_type: [
-        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'],
-         'links': ['master'], u'name': 'sh'},
-        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'],
-         u'name': 'master'},
-        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'],
-         'links': ['master'], u'name': 'indexer'}],
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'dsh', 'ports': ['8000', '8089', '22'],
+         'links': ['master'], u'name': 'dsp'},
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'dsp', 'ports': ['8000', '8089', '22'],
+         u'name': 'dsp'}],
     ShcEnvironment.env_type: [
         {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'],
          'links': ['master'], u'name': 'sh'},
@@ -197,24 +267,24 @@ ENV_DICT_MAPPING = {
          'links': ['master'], u'name': 'indexer'}]
 }
 
-if __name__ == "__main__":
-    # os.environ["FIG_FILE"] = "/Users/weiwang/work/github/rider/rider/pkg/fig.yml"
-    # os.environ["DOCKER_HOST"] = 'tcp://192.168.59.103:2376'
-    # os.environ["DOCKER_TLS_VERIFY"] = '1'
-    # os.environ["DOCKER_CERT_PATH"] = '/Users/weiwang/.boot2docker/certs/boot2docker-vm'
-    # testenv = Environment.get_environment_by_name('jacktestapi2')
-    # testenv = Environment.get_environments()
-    # print testenv[0].indexer.machines
+# if __name__ == "__main__":
 
-    myEnv = Environment.create_environment("cluster", "jacktestapi2")
+# testenv = Environment.get_environment_by_name('jacktestapi2')
+# testenv = Environment.get_environments()
+# print testenv[0].indexer.machines
+
+# myEnv = Environment.create_environment("cluster", "jacktestapi")
+# myEnv.bootstrap()
+
+# myEnv.get_service_names()
+#
+# myEnv.up()
+# myEnv.indexer.scale(2)
+#
+# print myEnv.indexer.machines[0].name
+# Environment.get_environments()
+# env = Environment.get_environment_by_name('jacktestapi_cluster')
+# print env.service_list
+# env.clean()
+# print 1
 
-    # myEnv.get_service_names()
-    #
-    myEnv.up()
-    # myEnv.indexer.scale(2)
-    #
-    # print myEnv.indexer.machines[0].name
-    # Environment.get_environments()
-    env = Environment.get_environment_by_name('jacktestapi2_cluster')
-    print env.service_list
-    print 1
